import os
import yaml
import traceback
from collections import OrderedDict


def get_samples(samplefile, size_batches, start_batch_nb=1):
    samples = OrderedDict()
    samples_batch = []
    with open(samplefile) as fin:
        for line in fin:
            samples_batch.append(line.rstrip())
            if len(samples_batch) == size_batches:
                samples["batch%03d" % start_batch_nb] = samples_batch
                samples_batch = []
                start_batch_nb += 1
    if len(samples_batch) > 0:
        samples["batch%03d" % start_batch_nb] = samples_batch
    return samples


def get_samples_align(samples_file):
    samples = {}
    with open(samples_file) as smples:
        try:
            samples = yaml.load(smples)
        except yaml.YAMLError:
            traceback.print_exc()
            raise Exception("Error: sample file is not a valid YAML file")

    if not isinstance(samples, dict):
        raise Exception("Error: sample file is not valid")

    for sample, files in samples.items():
        if not isinstance(sample, str):
            samples[str(sample)] = samples[sample]
            del samples[sample]
        if not isinstance(files, dict):
            raise Exception("Error: sample file is not valid")
        if "reads1" not in files and "reads" not in files:
            raise Exception("Invalid sample file: each sample must have a reads1 or a reads key")
        if "reads" in files and "reads1" in files:
            raise Exception("Invalid sample file: a sample can't have both reads and reads1 key")
        if "reads" in files:
            files["reads1"] = files["reads"]
            del files["reads"]
        for file in files:
            files[file] = os.path.abspath(files[file])

    return samples
